@@ -1,4 +1,5 @@
 """Root package info."""
+
 import logging
 import os
 
@@ -21,10 +22,8 @@ if not _root_logger.hasHandlers():
     _logger.propagate = False
 
 
-from lightning_app import components  # noqa: E402, F401
-
 if os.path.isfile(os.path.join(os.path.dirname(__file__), "__about__.py")):
-    from lightning_app.__about__ import *  # noqa: F401, F403
+    from lightning_app.__about__ import *  # noqa: F403
 if "__version__" not in locals():
     if os.path.isfile(os.path.join(os.path.dirname(__file__), "__version__.py")):
         from lightning_app.__version__ import version as __version__
@@ -34,7 +33,6 @@ if "__version__" not in locals():
 from lightning_app.core.app import LightningApp  # noqa: E402
 from lightning_app.core.flow import LightningFlow  # noqa: E402
 from lightning_app.core.work import LightningWork  # noqa: E402
-from lightning_app.perf import pdb  # noqa: E402
 from lightning_app.plugin.plugin import LightningPlugin  # noqa: E402
 from lightning_app.utilities.packaging.build_config import BuildConfig  # noqa: E402
 from lightning_app.utilities.packaging.cloud_compute import CloudCompute  # noqa: E402
@@ -46,5 +44,8 @@ __package_name__ = "lightning_app".split(".")[0]
 
 _PACKAGE_ROOT = os.path.dirname(__file__)
 _PROJECT_ROOT = os.path.dirname(os.path.dirname(_PACKAGE_ROOT))
+if __package_name__ == "lightning":
+    _PACKAGE_ROOT = os.path.dirname(_PACKAGE_ROOT)
+    _PROJECT_ROOT = os.path.dirname(_PROJECT_ROOT)
 
-__all__ = ["LightningApp", "LightningFlow", "LightningWork", "LightningPlugin", "BuildConfig", "CloudCompute", "pdb"]
+__all__ = ["LightningApp", "LightningFlow", "LightningWork", "LightningPlugin", "BuildConfig", "CloudCompute"]
