@@ -1,9 +1,8 @@
+from lightning_app import LightningApp, LightningFlow
 from placeholdername import ComponentA, ComponentB
 
-import lightning_app as L
 
-
-class LitApp(L.LightningFlow):
+class LitApp(LightningFlow):
     def __init__(self) -> None:
         super().__init__()
         self.component_a = ComponentA()
@@ -14,4 +13,4 @@ class LitApp(L.LightningFlow):
         self.component_b.run()
 
 
-app = L.LightningApp(LitApp())
+app = LightningApp(LitApp())
