@@ -6,11 +6,12 @@ To test a lightning_app:
 
 run_once runs your app through one cycle of the event loop and then terminates
 """
+
 import io
 import os
 from contextlib import redirect_stdout
 
-from lightning_app.testing.testing import application_testing, LightningTestApp
+from lightning_app.testing.testing import LightningTestApp, application_testing
 
 
 class LightningAppTestInt(LightningTestApp):
