@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import concurrent
+import contextlib
 import os
 import sys
 from functools import partial
@@ -29,7 +30,6 @@ from lightning_cloud.openapi import (
     Externalv1LightningappInstance,
     ProjectIdStorageBody,
     V1CloudSpace,
-    V1GetClusterResponse,
 )
 from rich.live import Live
 from rich.progress import BarColumn, DownloadColumn, Progress, TaskID, TextColumn
@@ -54,13 +54,11 @@ logger = Logger(__name__)
 @click.option("--zip", required=False, is_flag=True, default=False)
 def cp(src_path: str, dst_path: str, r: bool = False, recursive: bool = False, zip: bool = False) -> None:
     """Copy files between your local filesystem and the Lightning Cloud filesystem."""
-
     if sys.platform == "win32":
         print("`cp` isn't supported on windows. Open an issue on Github.")
         sys.exit(0)
 
     with Live(Spinner("point", text=Text("pending...", style="white")), transient=True) as live:
-
         pwd = _pwd()
 
         client = LightningClient(retry=False)
@@ -77,12 +75,14 @@ def cp(src_path: str, dst_path: str, r: bool = False, recursive: bool = False, z
             if zip:
                 return _error_and_exit("Zipping uploads isn't supported yet. Please, open a Github issue.")
             _upload_files(live, client, src_path, dst_path, pwd)
-        elif src_remote and not dst_remote:
+            return None
+        if src_remote and not dst_remote:
             if zip:
                 return _zip_files(live, src_path, dst_path)
             _download_files(live, client, src_path, dst_path, pwd)
-        else:
-            return _error_and_exit("Moving files locally isn't supported yet. Please, open a Github issue.")
+            return None
+
+        return _error_and_exit("Moving files locally isn't supported yet. Please, open a Github issue.")
 
 
 def _upload_files(live, client: LightningClient, local_src: str, remote_dst: str, pwd: str) -> str:
@@ -112,7 +112,7 @@ def _upload_files(live, client: LightningClient, local_src: str, remote_dst: str
     else:
         upload_paths = [local_src]
 
-    upload_urls = []
+    _upload_urls = []
 
     clusters = client.projects_service_list_project_cluster_bindings(project_id)
 
@@ -121,25 +121,24 @@ def _upload_files(live, client: LightningClient, local_src: str, remote_dst: str
     for upload_path in upload_paths:
         for cluster in clusters.clusters:
             filename = str(upload_path).replace(str(os.getcwd()), "")[1:]
-            if lit_resource:
-                filename = _get_prefix(os.path.join(remote_dst, filename), lit_resource)
-            else:
-                filename = "/" + filename
+            filename = _get_prefix(os.path.join(remote_dst, filename), lit_resource) if lit_resource else "/" + filename
 
             response = client.lightningapp_instance_service_upload_project_artifact(
                 project_id=project_id,
                 body=ProjectIdStorageBody(cluster_id=cluster.cluster_id, filename=filename),
                 async_req=True,
             )
-            upload_urls.append(response)
+            _upload_urls.append(response)
 
-    upload_urls = [upload_url.get().upload_url for upload_url in upload_urls]
+    upload_urls = []
+    for upload_url in _upload_urls:
+        upload_urls.extend(upload_url.get().urls)
 
     live.stop()
 
     if not upload_paths:
         print("There were no files to upload.")
-        return
+        return None
 
     progress = _get_progress_bar()
 
@@ -159,6 +158,8 @@ def _upload_files(live, client: LightningClient, local_src: str, remote_dst: str
     exception = next((e for e in results if isinstance(e, Exception)), None)
     if exception:
         _error_and_exit("We detected errors in uploading your files.")
+        return None
+    return None
 
 
 def _upload(source_file: str, presigned_url: ApplyResult, progress: Progress, task_id: TaskID) -> Optional[Exception]:
@@ -210,6 +211,7 @@ def _zip_files(live: Live, remote_src: str, local_dst: str) -> None:
     progress.stop()
 
     click.echo(f"Downloaded to {local_dst}")
+    return None
 
 
 def _download_files(live, client, remote_src: str, local_dst: str, pwd: str):
@@ -258,8 +260,8 @@ def _download_file(path: str, url: str, progress: Progress, task_id: TaskID) ->
     # Disable warning about making an insecure request
     urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
-    try:
-        request = requests.get(url, stream=True, verify=False)
+    with contextlib.suppress(ConnectionError):
+        request = requests.get(url, stream=True, verify=False)  # noqa: S501
 
         chunk_size = 1024
 
@@ -267,18 +269,13 @@ def _download_file(path: str, url: str, progress: Progress, task_id: TaskID) ->
             for chunk in request.iter_content(chunk_size=chunk_size):
                 fp.write(chunk)  # type: ignore
                 progress.update(task_id, advance=len(chunk))
-    except ConnectionError:
-        pass
 
 
 def _sanitize_path(path: str, pwd: str) -> Tuple[str, bool]:
     is_remote = _is_remote(path)
     if is_remote:
         path = _remove_remote(path)
-        if path == ".":
-            path = pwd
-        else:
-            path = os.path.join(pwd, path)
+        path = pwd if path == "." else os.path.join(pwd, path)
     return path, is_remote
 
 
@@ -308,11 +305,9 @@ def _get_project_id_and_resource(pwd: str) -> Tuple[str, Union[Externalv1Lightni
     lit_ressources = [lit_resource for lit_resource in lit_cloud_spaces if lit_resource.name == resource_name]
 
     if len(lit_ressources) == 0:
-
         lit_ressources = [lit_resource for lit_resource in lit_apps if lit_resource.name == resource_name]
 
         if len(lit_ressources) == 0:
-
             print(f"ERROR: There isn't any Lightning Ressource matching the name {resource_name}.")
             sys.exit(0)
 
@@ -336,16 +331,14 @@ def _get_progress_bar(**kwargs: Any) -> Progress:
     )
 
 
-def _storage_host(cluster: Union[V1GetClusterResponse, Externalv1Cluster]) -> str:
+def _storage_host(cluster: Externalv1Cluster) -> str:
     dev_host = os.environ.get("LIGHTNING_STORAGE_HOST")
     if dev_host:
         return dev_host
     return f"https://storage.{cluster.spec.driver.kubernetes.root_domain_name}"
 
 
-def _cluster_from_lit_resource(
-    lit_resource: Union[Externalv1LightningappInstance, V1CloudSpace]
-) -> Union[V1GetClusterResponse, Externalv1Cluster]:
+def _cluster_from_lit_resource(lit_resource: Union[Externalv1LightningappInstance, V1CloudSpace]) -> Externalv1Cluster:
     client = LightningClient()
     if isinstance(lit_resource, Externalv1LightningappInstance):
         return client.cluster_service_get_cluster(lit_resource.spec.cluster_id)
@@ -354,3 +347,4 @@ def _cluster_from_lit_resource(
     for cluster in clusters.clusters:
         if cluster.id == clusters.default_cluster:
             return cluster
+    return None
