@@ -1,7 +1,7 @@
-import lightning_app as L
+from lightning_app import LightningWork
 
 
-class TemplateComponent(L.LightningWork):
+class TemplateComponent(LightningWork):
     def __init__(self) -> None:
         super().__init__()
         self.value = 0
