@@ -1,9 +1,10 @@
-r"""
-To test a lightning component:
+r"""To test a lightning component:
 
 1. Init the component.
 2. call .run()
+
 """
+
 from placeholdername.component import TemplateComponent
 
 
