@@ -57,6 +57,7 @@ def connect_app(app_name_or_id: str):
     \b
     # once done, disconnect and go back to the standard lightning CLI commands
     lightning disconnect
+
     """
     from lightning_app.utilities.commands.base import _download_command
 
@@ -83,7 +84,6 @@ def connect_app(app_name_or_id: str):
             connect_app(app_name_or_id)
 
     elif app_name_or_id.startswith("localhost"):
-
         with Progress() as progress_bar:
             connecting = progress_bar.add_task("[magenta]Setting things up for you...", total=1.0)
 
@@ -112,7 +112,7 @@ def connect_app(app_name_or_id: str):
 
             for command_name, metadata in retriever.api_commands.items():
                 if "cls_path" in metadata:
-                    target_file = os.path.join(commands_folder, f"{command_name.replace(' ','_')}.py")
+                    target_file = os.path.join(commands_folder, f"{command_name.replace(' ', '_')}.py")
                     _download_command(
                         command_name,
                         metadata["cls_path"],
@@ -129,18 +129,17 @@ def connect_app(app_name_or_id: str):
         with open(connected_file, "w") as f:
             f.write(app_name_or_id + "\n")
 
-        click.echo("The lightning CLI now responds to app commands. Use 'lightning --help' to see them.")
+        click.echo("The lightning App CLI now responds to app commands. Use 'lightning_app --help' to see them.")
         click.echo(" ")
 
         Popen(
-            f"LIGHTNING_CONNECT_PPID={_PPID} {sys.executable} -m lightning --help",
+            f"LIGHTNING_CONNECT_PPID={_PPID} {sys.executable} -m lightning_app --help",
             shell=True,
             stdout=sys.stdout,
             stderr=sys.stderr,
         ).wait()
 
     elif matched_connection_path:
-
         matched_connected_file = os.path.join(matched_connection_path, "connect.txt")
         matched_commands = os.path.join(matched_connection_path, "commands")
         if os.path.isdir(matched_commands):
@@ -148,11 +147,11 @@ def connect_app(app_name_or_id: str):
             shutil.copytree(matched_commands, commands)
             shutil.copy(matched_connected_file, connected_file)
 
-        click.echo("The lightning CLI now responds to app commands. Use 'lightning --help' to see them.")
+        click.echo("The lightning App CLI now responds to app commands. Use 'lightning_app --help' to see them.")
         click.echo(" ")
 
         Popen(
-            f"LIGHTNING_CONNECT_PPID={_PPID} {sys.executable} -m lightning --help",
+            f"LIGHTNING_CONNECT_PPID={_PPID} {sys.executable} -m lightning_app --help",
             shell=True,
             stdout=sys.stdout,
             stderr=sys.stderr,
@@ -206,11 +205,11 @@ def connect_app(app_name_or_id: str):
             f.write(retriever.app_name + "\n")
             f.write(retriever.app_id + "\n")
 
-        click.echo("The lightning CLI now responds to app commands. Use 'lightning --help' to see them.")
+        click.echo("The lightning App CLI now responds to app commands. Use 'lightning_app --help' to see them.")
         click.echo(" ")
 
         Popen(
-            f"LIGHTNING_CONNECT_PPID={_PPID} {sys.executable} -m lightning --help",
+            f"LIGHTNING_CONNECT_PPID={_PPID} {sys.executable} -m lightning_app --help",
             shell=True,
             stdout=sys.stdout,
             stderr=sys.stderr,
@@ -239,7 +238,7 @@ def disconnect_app(logout: bool = False):
         if not logout:
             click.echo(
                 "You aren't connected to any Lightning App. "
-                "Please use `lightning connect app_name_or_id` to connect to one."
+                "Please use `lightning_app connect app_name_or_id` to connect to one."
             )
 
 
@@ -263,7 +262,7 @@ def _get_commands_folder() -> str:
 
 
 def _write_commands_metadata(api_commands):
-    metadata = {command_name: metadata for command_name, metadata in api_commands.items()}
+    metadata = dict(api_commands.items())
     metadata_path = os.path.join(_get_commands_folder(), ".meta.json")
     with open(metadata_path, "w") as f:
         json.dump(metadata, f)
@@ -283,7 +282,7 @@ def _list_app_commands(echo: bool = True) -> List[str]:
     metadata = _get_commands_metadata()
     metadata = {key.replace("_", " "): value for key, value in metadata.items()}
 
-    command_names = list(sorted(metadata.keys()))
+    command_names = sorted(metadata.keys())
     if not command_names:
         click.echo("The current Lightning App doesn't have commands.")
         return []
@@ -366,7 +365,7 @@ def _clean_lightning_connection():
 
 def _scan_lightning_connections(app_name_or_id):
     if not os.path.exists(_LIGHTNING_CONNECTION):
-        return
+        return None
 
     for ppid in os.listdir(_LIGHTNING_CONNECTION):
         try:
@@ -382,7 +381,7 @@ def _scan_lightning_connections(app_name_or_id):
         if not curr_app_name:
             continue
 
-        if app_name_or_id == curr_app_name or app_name_or_id == curr_app_id:
+        if app_name_or_id in (curr_app_name, curr_app_id):
             return connection_path
 
     return None
