@@ -1,16 +1,16 @@
 import inspect
-from typing import Any, Dict, TYPE_CHECKING, Union
-
-from core.state import ProgressBarState, TrainerState
+from typing import TYPE_CHECKING, Any, Dict, Union
 
 import pytorch_lightning as pl
-from lightning_app.storage import Path
+from lightning_app.storage.path import Path
 from lightning_app.utilities.app_helpers import Logger
 from pytorch_lightning import Callback
 from pytorch_lightning.callbacks.progress.progress_bar import get_standard_metrics
 from pytorch_lightning.loggers import TensorBoardLogger, WandbLogger
 from pytorch_lightning.utilities.parsing import collect_init_args
 
+from core.state import ProgressBarState, TrainerState
+
 if TYPE_CHECKING:
     from core.components.script_runner import ScriptRunner
 
@@ -158,13 +158,9 @@ class PLAppProgressTracker(Callback):
         return trainer.fit_loop.epoch_loop.batch_progress.current.processed
 
     def _val_batch_idx(self, trainer: "pl.Trainer") -> int:
-        if trainer.state.fn == "fit":
-            loop = trainer.fit_loop.epoch_loop.val_loop
-        else:
-            loop = trainer.validate_loop
+        loop = trainer.fit_loop.epoch_loop.val_loop if trainer.state.fn == "fit" else trainer.validate_loop
 
-        current_batch_idx = loop.epoch_loop.batch_progress.current.processed
-        return current_batch_idx
+        return loop.epoch_loop.batch_progress.current.processed
 
     def _test_batch_idx(self, trainer: "pl.Trainer") -> int:
         return trainer.test_loop.epoch_loop.batch_progress.current.processed
@@ -269,8 +265,7 @@ class PLAppSummary(Callback):
     def _sanitize_trainer_init_args(self, init_args: Dict[str, Any]) -> Dict[str, str]:
         if init_args["callbacks"]:
             init_args["callbacks"] = [c.__class__.__name__ for c in init_args["callbacks"]]
-        init_args = {k: str(v) for k, v in init_args.items()}
-        return init_args
+        return {k: str(v) for k, v in init_args.items()}
 
     def _sanitize_model_init_args(self, init_args: Dict[str, Any]) -> Dict[str, str]:
         return {k: str(v) for k, v in init_args.items()}
@@ -302,9 +297,11 @@ class PLAppArtifactsTracker(Callback):
         for logger in trainer.loggers:
             metadata = {"class_name": logger.__class__.__name__}
             if isinstance(logger, WandbLogger) and not logger._offline:
-                metadata.update(
-                    {"username": logger.experiment.entity, "project_name": logger.name, "run_id": logger.version}
-                )
+                metadata.update({
+                    "username": logger.experiment.entity,
+                    "project_name": logger.name,
+                    "run_id": logger.version,
+                })
 
             if metadata and metadata not in self.work.logger_metadatas:
                 self.work.logger_metadatas.append(metadata)
