@@ -4,13 +4,12 @@ from unittest.mock import Mock
 import pytest
 from core.callbacks import PLAppArtifactsTracker, PLAppProgressTracker, PLAppSummary
 from core.components.script_runner import ScriptRunner
-
-from lightning_app.storage import Path
+from lightning_app.storage.path import Path
 from pytorch_lightning import LightningModule, Trainer
 from pytorch_lightning.loggers import TensorBoardLogger
 
 
-@pytest.mark.parametrize("rank", (0, 1))
+@pytest.mark.parametrize("rank", [0, 1])
 def test_progress_tracker_enabled(rank):
     trainer = Mock()
     trainer.global_rank = rank
