@@ -1,6 +1,6 @@
 from lightning_app.components.multi_node.base import MultiNode
-from lightning_app.components.multi_node.lite import LiteMultiNode
+from lightning_app.components.multi_node.fabric import FabricMultiNode
 from lightning_app.components.multi_node.pytorch_spawn import PyTorchSpawnMultiNode
 from lightning_app.components.multi_node.trainer import LightningTrainerMultiNode
 
-__all__ = ["LiteMultiNode", "MultiNode", "PyTorchSpawnMultiNode", "LightningTrainerMultiNode"]
+__all__ = ["FabricMultiNode", "MultiNode", "PyTorchSpawnMultiNode", "LightningTrainerMultiNode"]
