@@ -15,9 +15,9 @@
 import warnings
 from typing import Any, Type
 
-from lightning_app import structures
 from lightning_app.core.flow import LightningFlow
 from lightning_app.core.work import LightningWork
+from lightning_app.structures import List as _List
 from lightning_app.utilities.cloud import is_running_in_cloud
 from lightning_app.utilities.packaging.cloud_compute import CloudCompute
 
@@ -37,10 +37,10 @@ class MultiNode(LightningFlow):
 
             import torch
 
-            import lightning_app as L
+            from lightning_app import LightningWork, CloudCompute
             from lightning.components import MultiNode
 
-            class AnyDistributedComponent(L.LightningWork):
+            class AnyDistributedComponent(LightningWork):
                 def run(
                     self,
                     main_address: str,
@@ -50,8 +50,8 @@ class MultiNode(LightningFlow):
                     print(f"ADD YOUR DISTRIBUTED CODE: {main_address} {main_port} {node_rank}")
 
 
-            compute = L.CloudCompute("gpu")
-            app = L.LightningApp(
+            compute = CloudCompute("gpu")
+            app = LightningApp(
                 MultiNode(
                     AnyDistributedComponent,
                     num_nodes=8,
@@ -67,6 +67,7 @@ class MultiNode(LightningFlow):
                 running locally.
             work_args: Arguments to be provided to the work on instantiation.
             work_kwargs: Keywords arguments to be provided to the work on instantiation.
+
         """
         super().__init__()
         if num_nodes > 1 and not is_running_in_cloud():
@@ -76,17 +77,15 @@ class MultiNode(LightningFlow):
                 " To run on multiple nodes in the cloud, launch your app with `--cloud`."
             )
             num_nodes = 1
-        self.ws = structures.List(
-            *[
-                work_cls(
-                    *work_args,
-                    cloud_compute=cloud_compute.clone(),
-                    **work_kwargs,
-                    parallel=True,
-                )
-                for _ in range(num_nodes)
-            ]
-        )
+        self.ws = _List(*[
+            work_cls(
+                *work_args,
+                cloud_compute=cloud_compute.clone(),
+                **work_kwargs,
+                parallel=True,
+            )
+            for _ in range(num_nodes)
+        ])
 
     def run(self) -> None:
         # 1. Wait for all works to be started !
@@ -95,7 +94,6 @@ class MultiNode(LightningFlow):
 
         # 2. Loop over all node machines
         for node_rank in range(len(self.ws)):
-
             # 3. Run the user code in a distributed way !
             self.ws[node_rank].run(
                 main_address=self.ws[0].internal_ip,
