@@ -12,13 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Any, Callable, Protocol, runtime_checkable, Type
+from typing import Any, Callable, Protocol, Type, runtime_checkable
 
 from lightning_app.components.multi_node.base import MultiNode
 from lightning_app.core.queues import MultiProcessQueue
 from lightning_app.core.work import LightningWork
 from lightning_app.utilities.packaging.cloud_compute import CloudCompute
-from lightning_app.utilities.proxies import _proxy_setattr, unwrap, WorkRunExecutor, WorkStateObserver
+from lightning_app.utilities.proxies import WorkRunExecutor, WorkStateObserver, _proxy_setattr, unwrap
 
 
 @runtime_checkable
@@ -81,7 +81,6 @@ class _PyTorchSpawnRunExecutor(WorkRunExecutor):
         node_rank: int,
         nprocs: int,
     ):
-
         import torch
 
         # 1. Setting distributed environment
