@@ -16,7 +16,7 @@ import importlib
 import os
 import warnings
 from dataclasses import dataclass
-from typing import Any, Callable, Protocol, runtime_checkable, Type
+from typing import Any, Callable, Protocol, Type, runtime_checkable
 
 from lightning_app.components.multi_node.base import MultiNode
 from lightning_app.components.multi_node.pytorch_spawn import _PyTorchSpawnRunExecutor
@@ -28,8 +28,7 @@ from lightning_app.utilities.tracer import Tracer
 @runtime_checkable
 class _LightningTrainerWorkProtocol(Protocol):
     @staticmethod
-    def run() -> None:
-        ...
+    def run() -> None: ...
 
 
 @dataclass
