@@ -15,10 +15,10 @@
 import os
 from typing import Any, Dict, List, Optional, Tuple, Type, Union
 
-from lightning_app import structures
 from lightning_app.components.python import TracerPythonScript
 from lightning_app.core.flow import LightningFlow
 from lightning_app.storage.path import Path
+from lightning_app.structures import List as _List
 from lightning_app.utilities.app_helpers import Logger
 from lightning_app.utilities.packaging.cloud_compute import CloudCompute
 
@@ -92,7 +92,7 @@ class PyTorchLightningScriptRunner(TracerPythonScript):
             if isinstance(v, LightningCLI):
                 trainer = v.trainer
                 break
-            elif isinstance(v, Trainer):
+            if isinstance(v, Trainer):
                 trainer = v
                 break
         else:
@@ -159,6 +159,7 @@ class LightningTrainerScript(LightningFlow):
             cloud_compute: The cloud compute object used in the cloud.
             sanity_serving: Whether to validate that the model correctly implements
                 the ServableModule API
+
         """
         super().__init__()
         self.script_path = script_path
@@ -168,7 +169,7 @@ class LightningTrainerScript(LightningFlow):
         self._script_runner = script_runner
         self._script_runner_kwargs = script_runner_kwargs
 
-        self.ws = structures.List()
+        self.ws = _List()
         for node_rank in range(self.num_nodes):
             self.ws.append(
                 self._script_runner(
