@@ -13,9 +13,11 @@
 # limitations under the License.
 
 import asyncio
+import contextlib
 import json
 import os
 import queue
+import socket
 import sys
 import traceback
 from copy import deepcopy
@@ -28,7 +30,7 @@ from typing import Dict, List, Mapping, Optional, Union
 
 import uvicorn
 from deepdiff import DeepDiff, Delta
-from fastapi import FastAPI, File, HTTPException, Request, Response, status, UploadFile, WebSocket
+from fastapi import FastAPI, File, HTTPException, Request, Response, UploadFile, WebSocket, status
 from fastapi.middleware.cors import CORSMiddleware
 from fastapi.params import Header
 from fastapi.responses import HTMLResponse, JSONResponse
@@ -47,22 +49,15 @@ from lightning_app.core.constants import (
     FRONTEND_DIR,
     get_cloud_queue_type,
 )
+from lightning_app.core.flow import LightningFlow
 from lightning_app.core.queues import QueuingSystem
+from lightning_app.core.work import LightningWork
 from lightning_app.storage import Drive
 from lightning_app.utilities.app_helpers import InMemoryStateStore, Logger, StateStore
 from lightning_app.utilities.app_status import AppStatus
 from lightning_app.utilities.cloud import is_running_in_cloud
 from lightning_app.utilities.component import _context
 from lightning_app.utilities.enum import ComponentContext, OpenAPITags
-from lightning_app.utilities.imports import _is_starsessions_available
-
-if _is_starsessions_available():
-    from starsessions import SessionMiddleware
-else:
-
-    class SessionMiddleware:
-        pass
-
 
 # TODO: fixed uuid for now, it will come from the FastAPI session
 TEST_SESSION_UUID = "1234"
@@ -71,9 +66,9 @@ STATE_EVENT = "State changed"
 
 frontend_static_dir = os.path.join(FRONTEND_DIR, "static")
 
-api_app_delta_queue: Queue = None
+api_app_delta_queue: Optional[Queue] = None
 
-template = {"ui": {}, "app": {}}
+template: dict = {"ui": {}, "app": {}}
 templates = Jinja2Templates(directory=FRONTEND_DIR)
 
 # TODO: try to avoid using global var for state store
@@ -98,8 +93,8 @@ logger = Logger(__name__)
 class UIRefresher(Thread):
     def __init__(
         self,
-        api_publish_state_queue,
-        api_response_queue,
+        api_publish_state_queue: Queue,
+        api_response_queue: Queue,
         refresh_interval: float = 0.1,
     ) -> None:
         super().__init__(daemon=True)
@@ -108,7 +103,7 @@ class UIRefresher(Thread):
         self._exit_event = Event()
         self.refresh_interval = refresh_interval
 
-    def run(self):
+    def run(self) -> None:
         # TODO: Create multiple threads to handle the background logic
         # TODO: Investigate the use of `parallel=True`
         try:
@@ -116,28 +111,24 @@ class UIRefresher(Thread):
                 self.run_once()
                 # Note: Sleep to reduce queue calls.
                 sleep(self.refresh_interval)
-        except Exception as e:
-            logger.error(traceback.print_exc())
-            raise e
+        except Exception as ex:
+            traceback.print_exc()
+            raise ex
 
-    def run_once(self):
-        try:
+    def run_once(self) -> None:
+        with contextlib.suppress(queue.Empty):
             global app_status
             state, app_status = self.api_publish_state_queue.get(timeout=0)
             with lock:
                 global_app_state_store.set_app_state(TEST_SESSION_UUID, state)
-        except queue.Empty:
-            pass
 
-        try:
+        with contextlib.suppress(queue.Empty):
             responses = self.api_response_queue.get(timeout=0)
             with lock:
                 # TODO: Abstract the responses store to support horizontal scaling.
                 global responses_store
                 for response in responses:
                     responses_store[response["id"]] = response["response"]
-        except queue.Empty:
-            pass
 
     def join(self, timeout: Optional[float] = None) -> None:
         self._exit_event.set()
@@ -175,9 +166,6 @@ fastapi_service.add_middleware(
     allow_headers=["*"],
 )
 
-if _is_starsessions_available():
-    fastapi_service.add_middleware(SessionMiddleware, secret_key="secret", autoload=True)
-
 
 # General sequence is:
 # * an update is generated in the UI
@@ -216,7 +204,7 @@ async def get_state(
         return state
 
 
-def _get_component_by_name(component_name: str, state):
+def _get_component_by_name(component_name: str, state: dict) -> Union[LightningFlow, LightningWork]:
     child = state
     for child_name in component_name.split(".")[1:]:
         try:
@@ -231,7 +219,7 @@ def _get_component_by_name(component_name: str, state):
 
 
 @fastapi_service.get("/api/v1/layout", response_class=JSONResponse)
-async def get_layout() -> Mapping:
+async def get_layout() -> str:
     with lock:
         x_lightning_session_uuid = TEST_SESSION_UUID
         state = global_app_state_store.get_app_state(x_lightning_session_uuid)
@@ -240,7 +228,7 @@ async def get_layout() -> Mapping:
         for la in layout:
             if la["content"].startswith("root."):
                 la["content"] = _get_component_by_name(la["content"], state)
-        return layout
+        return json.dumps(layout)
 
 
 @fastapi_service.get("/api/v1/spec", response_class=JSONResponse)
@@ -270,8 +258,8 @@ async def post_delta(
     x_lightning_session_uuid: Optional[str] = Header(None),
     x_lightning_session_id: Optional[str] = Header(None),
 ) -> Optional[Dict]:
-    """This endpoint is used to make an update to the app state using delta diff, mainly used by streamlit to
-    update the state."""
+    """This endpoint is used to make an update to the app state using delta diff, mainly used by streamlit to update
+    the state."""
 
     if x_lightning_session_uuid is None:
         raise Exception("Missing X-Lightning-Session-UUID header")
@@ -283,7 +271,9 @@ async def post_delta(
         return {"status": "failure", "reason": "This endpoint is disabled."}
 
     body: Dict = await request.json()
+    assert api_app_delta_queue is not None
     api_app_delta_queue.put(_DeltaRequest(delta=Delta(body["delta"])))
+    return None
 
 
 @fastapi_service.post("/api/v1/state")
@@ -320,11 +310,13 @@ async def post_state(
         state = body["state"]
         last_state = global_app_state_store.get_served_state(x_lightning_session_uuid)
         deep_diff = DeepDiff(last_state, state, verbose_level=2)
+    assert api_app_delta_queue is not None
     api_app_delta_queue.put(_DeltaRequest(delta=Delta(deep_diff)))
+    return None
 
 
 @fastapi_service.put("/api/v1/upload_file/{filename}")
-async def upload_file(response: Response, filename: str, uploaded_file: UploadFile = File(...)):
+async def upload_file(response: Response, filename: str, uploaded_file: UploadFile = File(...)) -> Union[str, dict]:
     if not ENABLE_UPLOAD_ENDPOINT:
         response.status_code = status.HTTP_405_METHOD_NOT_ALLOWED
         return {"status": "failure", "reason": "This endpoint is disabled."}
@@ -346,7 +338,7 @@ async def upload_file(response: Response, filename: str, uploaded_file: UploadFi
                 f.write(content)
                 done = content == b""
 
-        with _context(ComponentContext.WORK):
+        with _context(str(ComponentContext.WORK)):
             drive.put(filename)
     return f"Successfully uploaded '{filename}' to the Drive"
 
@@ -370,7 +362,7 @@ async def get_annotations() -> Union[List, Dict]:
 
 
 @fastapi_service.get("/healthz", status_code=200)
-async def healthz(response: Response):
+async def healthz(response: Response) -> dict:
     """Health check endpoint used in the cloud FastAPI servers to check the status periodically."""
     # check the queue status only if running in cloud
     if is_running_in_cloud():
@@ -392,7 +384,7 @@ async def healthz(response: Response):
 # Creates session websocket connection to notify client about any state changes
 # The websocket instance needs to be stored based on session id so it is accessible in the api layer
 @fastapi_service.websocket("/api/v1/ws")
-async def websocket_endpoint(websocket: WebSocket):
+async def websocket_endpoint(websocket: WebSocket) -> None:
     await websocket.accept()
     if not ENABLE_STATE_WEBSOCKET:
         await websocket.close()
@@ -410,7 +402,7 @@ async def websocket_endpoint(websocket: WebSocket):
     await websocket.close()
 
 
-async def api_catch_all(request: Request, full_path: str):
+async def api_catch_all(request: Request, full_path: str) -> None:
     raise HTTPException(status_code=404, detail="Not found")
 
 
@@ -418,22 +410,22 @@ async def api_catch_all(request: Request, full_path: str):
 fastapi_service.mount("/static", StaticFiles(directory=frontend_static_dir, check_dir=False), name="static")
 
 
-async def frontend_route(request: Request, full_path: str):
+async def frontend_route(request: Request, full_path: str):  # type: ignore[no-untyped-def]
     if "pytest" in sys.modules:
         return ""
     return templates.TemplateResponse("index.html", {"request": request})
 
 
-def register_global_routes():
+def register_global_routes() -> None:
     # Catch-all for nonexistent API routes (since we define a catch-all for client-side routing)
     fastapi_service.get("/api{full_path:path}", response_class=JSONResponse)(api_catch_all)
     fastapi_service.get("/{full_path:path}", response_class=HTMLResponse)(frontend_route)
 
 
 class LightningUvicornServer(uvicorn.Server):
-    has_started_queue = None
+    has_started_queue: Optional[Queue] = None
 
-    def run(self, sockets=None):
+    def run(self, sockets: Optional[List[socket.socket]] = None) -> None:
         self.config.setup_event_loop()
         loop = asyncio.get_event_loop()
         asyncio.ensure_future(self.serve(sockets=sockets))
@@ -441,25 +433,25 @@ class LightningUvicornServer(uvicorn.Server):
             asyncio.ensure_future(self.check_is_started(self.has_started_queue))
         loop.run_forever()
 
-    async def check_is_started(self, queue):
+    async def check_is_started(self, queue: Queue) -> None:
         while not self.started:
             await asyncio.sleep(0.1)
         queue.put("SERVER_HAS_STARTED")
 
 
 def start_server(
-    api_publish_state_queue,
-    api_delta_queue,
-    api_response_queue,
+    api_publish_state_queue: Queue,
+    api_delta_queue: Queue,
+    api_response_queue: Queue,
     has_started_queue: Optional[Queue] = None,
-    host="127.0.0.1",
-    port=8000,
+    host: str = "127.0.0.1",
+    port: int = 8000,
     root_path: str = "",
     uvicorn_run: bool = True,
     spec: Optional[List] = None,
     apis: Optional[List[_HttpMethod]] = None,
     app_state_store: Optional[StateStore] = None,
-):
+) -> UIRefresher:
     global api_app_delta_queue
     global global_app_state_store
     global app_spec
@@ -469,7 +461,7 @@ def start_server(
     api_app_delta_queue = api_delta_queue
 
     if app_state_store is not None:
-        global_app_state_store = app_state_store
+        global_app_state_store = app_state_store  # type: ignore[assignment]
 
     global_app_state_store.add(TEST_SESSION_UUID)
 
@@ -485,7 +477,7 @@ def start_server(
 
     if uvicorn_run:
         host = host.split("//")[-1] if "//" in host else host
-        if host == "0.0.0.0":
+        if host == "0.0.0.0":  # noqa: S104
             logger.info("Your app has started.")
         else:
             logger.info(f"Your app has started. View it in your browser: http://{host}:{port}/view")
