@@ -17,26 +17,25 @@ import warnings
 from copy import deepcopy
 from datetime import datetime
 from types import FrameType
-from typing import Any, cast, Dict, Generator, Iterable, List, Optional, Tuple, TYPE_CHECKING, Union
+from typing import TYPE_CHECKING, Any, Dict, Generator, Iterable, List, Optional, Tuple, Union, cast
 
 from deepdiff import DeepHash
 
 from lightning_app.core.work import LightningWork
 from lightning_app.frontend import Frontend
-from lightning_app.storage import Path
-from lightning_app.storage.drive import _maybe_create_drive, Drive
+from lightning_app.storage.drive import Drive, _maybe_create_drive
+from lightning_app.storage.path import Path
 from lightning_app.utilities.app_helpers import _is_json_serializable, _LightningAppRef, _set_child_name, is_overridden
 from lightning_app.utilities.component import _sanitize_state
-from lightning_app.utilities.exceptions import ExitAppException
+from lightning_app.utilities.exceptions import ExitAppException, LightningFlowException
 from lightning_app.utilities.introspection import _is_init_context, _is_run_context
-from lightning_app.utilities.packaging.cloud_compute import _maybe_create_cloud_compute, CloudCompute
+from lightning_app.utilities.packaging.cloud_compute import CloudCompute, _maybe_create_cloud_compute
 
 if TYPE_CHECKING:
     from lightning_app.runners.backends.backend import Backend
 
 
 class LightningFlow:
-
     _INTERNAL_STATE_VARS = {
         # Internal protected variables that are still part of the state (even though they are prefixed with "_")
         "_paths",
@@ -109,8 +108,8 @@ class LightningFlow:
             >>> flow.run()
             >>> assert flow.counter == 1
             >>> assert flow.state["vars"]["counter"] == 1
-        """
 
+        """
         self._state: set = set()
         self._name: str = ""
         self._flows: set = set()
@@ -122,7 +121,7 @@ class LightningFlow:
         self._paths: dict = {}
         self._backend: Optional["Backend"] = None
         # tuple instead of a list so that it cannot be modified without using the setter
-        self._lightningignore: Tuple[str, ...] = tuple()
+        self._lightningignore: Tuple[str, ...] = ()
 
     @property
     def name(self) -> str:
@@ -154,7 +153,6 @@ class LightningFlow:
             value = Path(value)
 
         if self._is_state_attribute(name):
-
             if hasattr(self, name):
                 if name in self._flows and value != getattr(self, name):
                     raise AttributeError(f"Cannot set attributes as the flow can't be changed once defined: {name}")
@@ -240,6 +238,7 @@ class LightningFlow:
                 )
 
         super().__setattr__(name, value)
+        return None
 
     @staticmethod
     def _attach_backend(flow: "LightningFlow", backend: "Backend") -> None:
@@ -365,6 +364,7 @@ class LightningFlow:
         Arguments:
             provided_state: The state to be reloaded
             recurse: Whether to apply the state down children.
+
         """
         for k, v in provided_state["vars"].items():
             if isinstance(v, Dict):
@@ -391,6 +391,12 @@ class LightningFlow:
             print(end_msg)
         raise ExitAppException
 
+    def fail(self, end_msg: str = "") -> None:
+        """Method used to exit and fail the application."""
+        if end_msg:
+            print(end_msg)
+        raise LightningFlowException
+
     def _exit(self, end_msg: str = "") -> None:
         """Used to exit the application.
 
@@ -398,6 +404,7 @@ class LightningFlow:
 
         .. deprecated:: 1.9.0
             This function is deprecated and will be removed in 2.0.0. Use :meth:`stop` instead.
+
         """
         warnings.warn(
             DeprecationWarning(
@@ -413,6 +420,7 @@ class LightningFlow:
         (prefixed by '__') attributes are not.
 
         Exceptions are listed in the `_INTERNAL_STATE_VARS` class variable.
+
         """
         return name in LightningFlow._INTERNAL_STATE_VARS or not name.startswith("_")
 
@@ -489,6 +497,7 @@ class LightningFlow:
                 </div>
             </div>
             <br />
+
         """
         if not user_key:
             frame = cast(FrameType, inspect.currentframe()).f_back
@@ -533,8 +542,8 @@ class LightningFlow:
             if app:
                 app._register_schedule(call_hash, schedule_metadata)
             return True
-        else:
-            return self._calls["scheduling"][call_hash]["running"]
+
+        return self._calls["scheduling"][call_hash]["running"]
 
     def _enable_schedule(self, call_hash: str) -> None:
         self._calls["scheduling"][call_hash]["running"] = True
@@ -628,8 +637,9 @@ class LightningFlow:
                 </div>
             </div>
             <br />
+
         """
-        return [dict(name=name, content=component) for (name, component) in self.flows.items()]
+        return [{"name": name, "content": component} for (name, component) in self.flows.items()]
 
     def experimental_iterate(self, iterable: Iterable, run_once: bool = True, user_key: str = "") -> Generator:
         """This method should always be used with any kind of iterable to ensure its fault tolerant.
@@ -641,6 +651,7 @@ class LightningFlow:
             run_once: Whether to run the entire iteration only once.
                 Otherwise, it would restart from the beginning.
             user_key: Key to be used to track the caching mechanism.
+
         """
         if not isinstance(iterable, Iterable):
             raise TypeError(f"An iterable should be provided to `self.iterate` method. Found {iterable}")
@@ -705,11 +716,12 @@ class LightningFlow:
 
         .. code-block:: bash
 
-            lightning run app app.py
+            lightning_app run app app.py
 
         .. code-block:: bash
 
-            lightning my_command_name --args name=my_own_name
+            lightning_app my_command_name --args name=my_own_name
+
         """
         raise NotImplementedError
 
@@ -730,7 +742,7 @@ class LightningFlow:
                 name: str
 
 
-            class Flow(L.LightningFlow):
+            class Flow(LightningFlow):
                 def __init__(self):
                     super().__init__()
                     self.names = []
@@ -743,6 +755,7 @@ class LightningFlow:
 
         Once the app is running, you can access the Swagger UI of the app
         under the ``/docs`` route.
+
         """
         raise NotImplementedError
 
@@ -767,10 +780,8 @@ class LightningFlow:
 
         .. code-block:: python
 
-            import lightning_app as L
 
-
-            class Work(L.LightningWork):
+            class Work(LightningWork):
                 def __init__(self):
                     super().__init__()
                     self.counter = 0
@@ -779,7 +790,7 @@ class LightningFlow:
                     self.counter += 1
 
 
-            class Flow(L.LightningFlow):
+            class Flow(LightningFlow):
                 def run(self):
                     # dynamically create a work.
                     if not getattr(self, "w", None):
@@ -807,6 +818,7 @@ class LightningFlow:
             children_states: The state of the dynamic children of this flow.
             strict: Whether to raise an exception if a dynamic
                 children hasn't been re-created.
+
         """
         self.set_state(flow_state, recurse=False)
         direct_children_states = {k: v for k, v in children_states.items() if "." not in k}
