@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import base64
 import multiprocessing
 import pickle
 import queue  # needed as import instead from/import for mocking in tests
@@ -20,14 +21,17 @@ import warnings
 from abc import ABC, abstractmethod
 from enum import Enum
 from pathlib import Path
-from typing import Any, Optional, Tuple
+from typing import Any, List, Optional, Tuple
 from urllib.parse import urljoin
 
+import backoff
 import requests
 from requests.exceptions import ConnectionError, ConnectTimeout, ReadTimeout
 
 from lightning_app.core.constants import (
+    BATCH_DELTA_COUNT,
     HTTP_QUEUE_REFRESH_INTERVAL,
+    HTTP_QUEUE_REQUESTS_PER_SECOND,
     HTTP_QUEUE_TOKEN,
     HTTP_QUEUE_URL,
     LIGHTNING_DIR,
@@ -74,10 +78,11 @@ class QueuingSystem(Enum):
     def get_queue(self, queue_name: str) -> "BaseQueue":
         if self == QueuingSystem.MULTIPROCESS:
             return MultiProcessQueue(queue_name, default_timeout=STATE_UPDATE_TIMEOUT)
-        elif self == QueuingSystem.REDIS:
+        if self == QueuingSystem.REDIS:
             return RedisQueue(queue_name, default_timeout=REDIS_QUEUES_READ_DEFAULT_TIMEOUT)
-        else:
-            return HTTPQueue(queue_name, default_timeout=STATE_UPDATE_TIMEOUT)
+        return RateLimitedQueue(
+            HTTPQueue(queue_name, default_timeout=STATE_UPDATE_TIMEOUT), HTTP_QUEUE_REQUESTS_PER_SECOND
+        )
 
     def get_api_response_queue(self, queue_id: Optional[str] = None) -> "BaseQueue":
         queue_name = f"{queue_id}_{API_RESPONSE_QUEUE_CONSTANT}" if queue_id else API_RESPONSE_QUEUE_CONSTANT
@@ -182,14 +187,30 @@ class BaseQueue(ABC):
         timeout:
             Read timeout in seconds, in case of input timeout is 0, the `self.default_timeout` is used.
             A timeout of None can be used to block indefinitely.
+
         """
         pass
 
+    @abstractmethod
+    def batch_get(self, timeout: Optional[float] = None, count: Optional[int] = None) -> List[Any]:
+        """Returns the left most elements of the queue.
+
+        Parameters
+        ----------
+        timeout:
+            Read timeout in seconds, in case of input timeout is 0, the `self.default_timeout` is used.
+            A timeout of None can be used to block indefinitely.
+        count:
+            The number of element to get from the queue
+
+        """
+
     @property
     def is_running(self) -> bool:
         """Returns True if the queue is running, False otherwise.
 
         Child classes should override this property and implement custom logic as required
+
         """
         return True
 
@@ -209,6 +230,12 @@ class MultiProcessQueue(BaseQueue):
             timeout = self.default_timeout
         return self.queue.get(timeout=timeout, block=(timeout is None))
 
+    def batch_get(self, timeout: Optional[float] = None, count: Optional[int] = None) -> List[Any]:
+        if timeout == 0:
+            timeout = self.default_timeout
+        # For multiprocessing, we can simply collect the latest upmost element
+        return [self.queue.get(timeout=timeout, block=(timeout is None))]
+
 
 class RedisQueue(BaseQueue):
     @requires("redis")
@@ -244,7 +271,7 @@ class RedisQueue(BaseQueue):
         self.redis = redis.Redis(host=self.host, port=self.port, password=self.password)
 
     def put(self, item: Any) -> None:
-        from lightning_app import LightningWork
+        from lightning_app.core.work import LightningWork
 
         is_work = isinstance(item, LightningWork)
 
@@ -286,8 +313,8 @@ class RedisQueue(BaseQueue):
         timeout:
             Read timeout in seconds, in case of input timeout is 0, the `self.default_timeout` is used.
             A timeout of None can be used to block indefinitely.
-        """
 
+        """
         if timeout is None:
             # this means it's blocking in redis
             timeout = 0
@@ -307,6 +334,9 @@ class RedisQueue(BaseQueue):
             raise queue.Empty
         return pickle.loads(out[1])
 
+    def batch_get(self, timeout: Optional[float] = None, count: Optional[int] = None) -> Any:
+        return [self.get(timeout=timeout)]
+
     def clear(self) -> None:
         """Clear all elements in the queue."""
         self.redis.delete(self.name)
@@ -345,6 +375,47 @@ class RedisQueue(BaseQueue):
         return cls(**state)
 
 
+class RateLimitedQueue(BaseQueue):
+    def __init__(self, queue: BaseQueue, requests_per_second: float):
+        """This is a queue wrapper that will block on get or put calls if they are made too quickly.
+
+        Args:
+            queue: The queue to wrap.
+            requests_per_second: The target number of get or put requests per second.
+
+        """
+        self.name = queue.name
+        self.default_timeout = queue.default_timeout
+
+        self._queue = queue
+        self._seconds_per_request = 1 / requests_per_second
+
+        self._last_get = 0.0
+
+    @property
+    def is_running(self) -> bool:
+        return self._queue.is_running
+
+    def _wait_until_allowed(self, last_time: float) -> None:
+        t = time.time()
+        diff = t - last_time
+        if diff < self._seconds_per_request:
+            time.sleep(self._seconds_per_request - diff)
+
+    def get(self, timeout: Optional[float] = None) -> Any:
+        self._wait_until_allowed(self._last_get)
+        self._last_get = time.time()
+        return self._queue.get(timeout=timeout)
+
+    def batch_get(self, timeout: Optional[float] = None, count: Optional[int] = None) -> Any:
+        self._wait_until_allowed(self._last_get)
+        self._last_get = time.time()
+        return self._queue.batch_get(timeout=timeout)
+
+    def put(self, item: Any) -> None:
+        return self._queue.put(item)
+
+
 class HTTPQueue(BaseQueue):
     def __init__(self, name: str, default_timeout: float) -> None:
         """
@@ -388,19 +459,30 @@ class HTTPQueue(BaseQueue):
         if timeout is None:
             while True:
                 try:
-                    return self._get()
+                    try:
+                        return self._get()
+                    except requests.exceptions.HTTPError:
+                        pass
                 except queue.Empty:
                     time.sleep(HTTP_QUEUE_REFRESH_INTERVAL)
 
         # make one request and return the result
         if timeout == 0:
-            return self._get()
+            try:
+                return self._get()
+            except requests.exceptions.HTTPError:
+                return None
 
         # timeout is some value - loop until the timeout is reached
         start_time = time.time()
         while (time.time() - start_time) < timeout:
             try:
-                return self._get()
+                try:
+                    return self._get()
+                except requests.exceptions.HTTPError:
+                    if timeout > self.default_timeout:
+                        return None
+                    raise queue.Empty
             except queue.Empty:
                 # Note: In theory, there isn't a need for a sleep as the queue shouldn't
                 # block the flow if the queue is empty.
@@ -409,7 +491,7 @@ class HTTPQueue(BaseQueue):
                 # than the default timeout
                 if timeout > self.default_timeout:
                     time.sleep(0.05)
-                pass
+        return None
 
     def _get(self) -> Any:
         try:
@@ -422,6 +504,21 @@ class HTTPQueue(BaseQueue):
             # we consider the queue is empty to avoid failing the app.
             raise queue.Empty
 
+    def batch_get(self, timeout: Optional[float] = None, count: Optional[int] = None) -> List[Any]:
+        try:
+            resp = self.client.post(
+                f"v1/{self.app_id}/{self._name_suffix}",
+                query_params={"action": "popCount", "count": str(count or BATCH_DELTA_COUNT)},
+            )
+            if resp.status_code == 204:
+                raise queue.Empty
+            return [pickle.loads(base64.b64decode(data)) for data in resp.json()]
+        except ConnectionError:
+            # Note: If the Http Queue service isn't available,
+            # we consider the queue is empty to avoid failing the app.
+            raise queue.Empty
+
+    @backoff.on_exception(backoff.expo, (RuntimeError, requests.exceptions.HTTPError))
     def put(self, item: Any) -> None:
         if not self.app_id:
             raise ValueError(f"The Lightning App ID couldn't be extracted from the queue name: {self.name}")
@@ -441,8 +538,11 @@ class HTTPQueue(BaseQueue):
         if not self.app_id:
             raise ValueError(f"App ID couldn't be extracted from the queue name: {self.name}")
 
-        val = self.client.get(f"/v1/{self.app_id}/{self._name_suffix}/length")
-        return int(val.text)
+        try:
+            val = self.client.get(f"/v1/{self.app_id}/{self._name_suffix}/length")
+            return int(val.text)
+        except requests.exceptions.HTTPError:
+            return 0
 
     @staticmethod
     def _split_app_id_and_queue_name(queue_name: str) -> Tuple[str, str]:
@@ -450,6 +550,7 @@ class HTTPQueue(BaseQueue):
 
         This can be brittle, as if the queue name creation logic changes, the response values from here wouldn't be
         accurate. Remove this eventually and let the Queue class take app id and name of the queue as arguments
+
         """
         if "_" not in queue_name:
             return "", queue_name
