@@ -1,6 +1,6 @@
 from lightning_app.runners.cloud import CloudRuntime
 from lightning_app.runners.multiprocess import MultiProcessRuntime
-from lightning_app.runners.runtime import dispatch, Runtime
+from lightning_app.runners.runtime import Runtime, dispatch
 from lightning_app.utilities.app_commands import run_app_commands
 from lightning_app.utilities.load_app import load_app_from_file
 
