@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import List, Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING, List, Optional
 
 from lightning_app.core.queues import QueuingSystem
 from lightning_app.runners.backends import Backend
@@ -23,9 +23,15 @@ if TYPE_CHECKING:
 
 
 class CloudBackend(Backend):
-    def __init__(self, entrypoint_file, queue_id: Optional[str] = None, status_update_interval: Optional[int] = None):
+    def __init__(
+        self,
+        entrypoint_file,
+        queue_id: Optional[str] = None,
+        status_update_interval: Optional[int] = None,
+        client_max_tries: Optional[int] = None,
+    ):
         super().__init__(entrypoint_file, queues=QueuingSystem.MULTIPROCESS, queue_id=queue_id)
-        self.client = LightningClient()
+        self.client = LightningClient(max_tries=client_max_tries)
 
     def create_work(self, app: "lightning_app.LightningApp", work: "lightning_app.LightningWork") -> None:
         raise NotImplementedError
