@@ -21,7 +21,7 @@ import subprocess
 import sys
 import tempfile
 import time
-from contextlib import contextmanager, nullcontext
+from contextlib import contextmanager
 from multiprocessing import Process
 from subprocess import Popen
 from time import sleep
@@ -30,14 +30,12 @@ from typing import Any, Callable, Dict, Generator, List, Optional, Type
 import requests
 from lightning_cloud.openapi import V1LightningappInstanceState
 from lightning_cloud.openapi.rest import ApiException
-from lightning_utilities.core.imports import package_available
 from requests import Session
 from rich import print
 from rich.color import ANSI_COLOR_NAMES
 
-from lightning_app import LightningApp, LightningFlow
 from lightning_app.cli.lightning_cli import run_app
-from lightning_app.core import constants
+from lightning_app.core import LightningApp, LightningFlow, constants
 from lightning_app.runners.multiprocess import MultiProcessRuntime
 from lightning_app.testing.config import _Config
 from lightning_app.utilities.app_logs import _app_logs_reader
@@ -46,7 +44,7 @@ from lightning_app.utilities.enum import CacheCallsKeys
 from lightning_app.utilities.imports import _is_playwright_available, requires
 from lightning_app.utilities.log import get_logfile
 from lightning_app.utilities.logs_socket_api import _LightningLogsSocketAPI
-from lightning_app.utilities.network import _configure_session, LightningClient
+from lightning_app.utilities.network import LightningClient, _configure_session
 from lightning_app.utilities.packaging.lightning_utils import get_dist_path_if_editable_install
 from lightning_app.utilities.proxies import ProxyWorkRun
 
@@ -150,10 +148,7 @@ def application_testing(lit_app_cls: Type[LightningTestApp] = LightningTestApp,
 
     from click.testing import CliRunner
 
-    patch1 = mock.patch("lightning_app.LightningApp", lit_app_cls)
-    # we need to patch both only with the mirror package
-    patch2 = mock.patch("lightning.LightningApp", lit_app_cls) if package_available("lightning") else nullcontext()
-    with patch1, patch2:
+    with mock.patch("lightning_app.LightningApp", lit_app_cls):
         original = sys.argv
         sys.argv = command_line
         runner = CliRunner()
@@ -233,8 +228,7 @@ def _fetch_app_by_name(client, project_id, name):
     ]
     if not len(lit_apps) == 1:
         raise ValueError(f"Expected to find just one app, found {len(lit_apps)}")
-    app = lit_apps[0]
-    return app
+    return lit_apps[0]
 
 
 @requires("playwright")
@@ -281,7 +275,7 @@ def run_app_in_cloud(
     token = res.json()["token"]
 
     # 3. Disconnect from the App if any.
-    Popen("lightning logout", shell=True).wait()
+    Popen("lightning_app logout", shell=True).wait()
 
     # 4. Launch the application in the cloud from the Lightning CLI.
     with tempfile.TemporaryDirectory() as tmpdir:
@@ -294,6 +288,9 @@ def run_app_in_cloud(
         shutil.copytree(app_folder, tmpdir, dirs_exist_ok=True)
         # TODO - add -no-cache to the command line.
         stdout_path = get_logfile(f"run_app_in_cloud_{name}")
+
+        cmd_extra_args = []
+
         with open(stdout_path, "w") as stdout:
             cmd = [
                 sys.executable,
@@ -307,7 +304,9 @@ def run_app_in_cloud(
                 name,
                 "--open-ui",
                 "false",
+                *cmd_extra_args,
             ]
+            print(f"Command: {cmd}")
             process = Popen((cmd + extra_args), cwd=tmpdir, env=env_copy, stdout=stdout, stderr=sys.stderr)
             process.wait()
 
@@ -339,9 +338,10 @@ def run_app_in_cloud(
         browser = p.chromium.launch(headless=bool(int(os.getenv("HEADLESS", "0"))))
         context = browser.new_context(
             # Eventually this will need to be deleted
-            http_credentials=HttpCredentials(
-                {"username": os.getenv("LAI_USER", "").strip(), "password": os.getenv("LAI_PASS", "")}
-            ),
+            http_credentials=HttpCredentials({
+                "username": os.getenv("LAI_USER", "").strip(),
+                "password": os.getenv("LAI_PASS", ""),
+            }),
             record_video_dir=os.path.join(_Config.video_location, TEST_APP_NAME),
             record_har_path=_Config.har_location,
         )
@@ -377,6 +377,8 @@ def run_app_in_cloud(
                 [constants.LIGHTNING_CLOUD_PROJECT_ID],
             )
 
+        admin_page.reload()
+
         view_page = context.new_page()
         i = 1
         while True:
@@ -385,10 +387,10 @@ def run_app_in_cloud(
 
             # wait until the app is running and openapi.json is ready
             if app.status.phase == V1LightningappInstanceState.RUNNING:
-                view_page.goto(f"{app.status.url}/view")
                 status_code = requests.get(f"{app.status.url}/openapi.json").status_code
                 if status_code == 200:
                     print("App is running, continuing with testing...")
+                    view_page.goto(f"{app.status.url}/view")
                     break
                 msg = f"Received status code {status_code} at {app.status.url!r}"
             elif app.status.phase not in (V1LightningappInstanceState.PENDING, V1LightningappInstanceState.NOT_STARTED):
@@ -446,6 +448,8 @@ def run_app_in_cloud(
             browser.close()
             Popen("lightning disconnect", shell=True).wait()
 
+            delete_cloud_lightning_apps(name=name)
+
 
 def wait_for(page, callback: Callable, *args: Any, **kwargs: Any) -> Any:
     import playwright
@@ -478,10 +482,24 @@ def _delete_lightning_app(client, project_id, app_id, app_name):
         print(f"Failed to delete {app_name}. Exception {ex}")
 
 
-def delete_cloud_lightning_apps():
+def _delete_cloud_space(client, project_id, cloud_space_id, app_name):
+    """Used to delete the parent cloudspace."""
+    print(f"Deleting {app_name} id: {cloud_space_id}")
+    try:
+        res = client.cloud_space_service_delete_cloud_space(
+            project_id=project_id,
+            id=cloud_space_id,
+        )
+        assert res == {}
+    except ApiException as ex:
+        print(f"Failed to delete {app_name}. Exception {ex}")
+
+
+def delete_cloud_lightning_apps(name=None):
     """Cleanup cloud apps that start with the name test-{PR_NUMBER}-{TEST_APP_NAME}.
 
     PR_NUMBER and TEST_APP_NAME are environment variables.
+
     """
 
     client = LightningClient()
@@ -492,20 +510,26 @@ def delete_cloud_lightning_apps():
         # Failed when the PR is running master or 'PR_NUMBER' isn't defined.
         pr_number = ""
 
-    app_name = os.getenv("TEST_APP_NAME", "")
+    app_name = os.getenv("TEST_APP_NAME", "").replace("_", "-")
 
     print(f"deleting apps for pr_number: {pr_number}, app_name: {app_name}")
     project_id = _get_project(client).project_id
     list_apps = client.lightningapp_instance_service_list_lightningapp_instances(project_id=project_id)
 
-    for lit_app in list_apps.lightningapps:
-        if pr_number and app_name and not lit_app.name.startswith(f"test-{pr_number}-{app_name}-"):
-            continue
-        _delete_lightning_app(client, project_id=project_id, app_id=lit_app.id, app_name=lit_app.name)
+    if pr_number and app_name:
+        for lit_app in list_apps.lightningapps:
+            if name == lit_app.name or (str(pr_number) in lit_app.name and app_name in lit_app.name):
+                _delete_lightning_app(client, project_id=project_id, app_id=lit_app.id, app_name=lit_app.name)
+                _delete_cloud_space(
+                    client, project_id=project_id, cloud_space_id=lit_app.spec.cloud_space_id, app_name=lit_app.name
+                )
 
-    print("deleting apps that were created more than 1 hour ago.")
+    print("deleting apps that were created more than 20 minutes ago.")
 
     for lit_app in list_apps.lightningapps:
-
-        if lit_app.created_at < datetime.datetime.now(lit_app.created_at.tzinfo) - datetime.timedelta(hours=1):
+        time_diff = datetime.datetime.now(lit_app.created_at.tzinfo) - lit_app.created_at
+        if time_diff > datetime.timedelta(minutes=20):
             _delete_lightning_app(client, project_id=project_id, app_id=lit_app.id, app_name=lit_app.name)
+            _delete_cloud_space(
+                client, project_id=project_id, cloud_space_id=lit_app.spec.cloud_space_id, app_name=lit_app.name
+            )
