@@ -44,6 +44,7 @@ def _extract_commands_from_file(file_name: str) -> CommandLines:
     """Extract all lines at the top of the file which contain commands to execute.
 
     The return struct contains a list of commands to execute with the corresponding line number the command executed on.
+
     """
     cl = CommandLines(
         file=file_name,
@@ -80,9 +81,10 @@ def _extract_commands_from_file(file_name: str) -> CommandLines:
 
 
 def _execute_app_commands(cl: CommandLines) -> None:
-    """open a subprocess shell to execute app commands.
+    """Open a subprocess shell to execute app commands.
 
     The calling app environment is used in the current environment the code is running in
+
     """
     for command, line_number in zip(cl.commands, cl.line_numbers):
         logger.info(f"Running app setup command: {command}")
@@ -106,21 +108,17 @@ def _execute_app_commands(cl: CommandLines) -> None:
 def run_app_commands(file: str) -> None:
     """Extract all lines at the top of the file which contain commands & execute them.
 
-    Commands to execute are comment lines whose first non-whitespace character
-    begins with the "bang" symbol (`!`).  After the first non comment line we
-    stop parsing the rest of the file. Running environment is preserved in the
+    Commands to execute are comment lines whose first non-whitespace character begins with the "bang" symbol (`!`).
+    After the first non comment line we stop parsing the rest of the file. Running environment is preserved in the
     subprocess shell.
 
     For example:
 
-        # some file           <--- not a command
-        # !echo "hello world" <--- a command
-        # ! pip install foo   <--- a command
-        # foo! bar            <--- not a command
-        import lightning_app      <--- not a command, end parsing.
+    # some file           <--- not a command # !echo "hello world" <--- a command # ! pip install foo   <--- a command #
+    foo! bar            <--- not a command import lightning_app      <--- not a command, end parsing.
+
+    where `echo "hello world" && pip install foo` would be executed in the current running environment.
 
-        where `echo "hello world" && pip install foo` would be executed in the current
-        running environment.
     """
     cl = _extract_commands_from_file(file_name=file)
     if len(cl.commands) == 0:
