@@ -28,12 +28,11 @@ from abc import ABC, abstractmethod
 from contextlib import contextmanager
 from copy import deepcopy
 from dataclasses import dataclass, field
-from typing import Any, Callable, Dict, Generator, List, Mapping, Optional, Tuple, Type, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Callable, Dict, Generator, List, Mapping, Optional, Tuple, Type
 from unittest.mock import MagicMock
 
 import websockets
 from deepdiff import Delta
-from lightning_cloud.openapi import AppinstancesIdBody, Externalv1LightningappInstance, V1LightningappInstanceState
 
 import lightning_app
 from lightning_app.utilities.exceptions import LightningAppStateException
@@ -49,7 +48,7 @@ logger = logging.getLogger(__name__)
 
 @dataclass
 class StateEntry:
-    """dataclass used to keep track the latest state shared through the app REST API."""
+    """Dataclass used to keep track the latest state shared through the app REST API."""
 
     app_state: Mapping = field(default_factory=dict)
     served_state: Mapping = field(default_factory=dict)
@@ -57,8 +56,7 @@ class StateEntry:
 
 
 class StateStore(ABC):
-    """Base class of State store that provides simple key, value store to keep track of app state, served app
-    state."""
+    """Base class of State store that provides simple key, value store to keep track of app state, served app state."""
 
     @abstractmethod
     def __init__(self):
@@ -76,32 +74,32 @@ class StateStore(ABC):
 
     @abstractmethod
     def get_app_state(self, k: str) -> Mapping:
-        """returns a stored appstate for an input key 'k'."""
+        """Returns a stored appstate for an input key 'k'."""
         pass
 
     @abstractmethod
     def get_served_state(self, k: str) -> Mapping:
-        """returns a last served app state for an input key 'k'."""
+        """Returns a last served app state for an input key 'k'."""
         pass
 
     @abstractmethod
     def get_served_session_id(self, k: str) -> str:
-        """returns session id for state of a key 'k'."""
+        """Returns session id for state of a key 'k'."""
         pass
 
     @abstractmethod
     def set_app_state(self, k: str, v: Mapping):
-        """sets the app state for state of a key 'k'."""
+        """Sets the app state for state of a key 'k'."""
         pass
 
     @abstractmethod
     def set_served_state(self, k: str, v: Mapping):
-        """sets the served state for state of a key 'k'."""
+        """Sets the served state for state of a key 'k'."""
         pass
 
     @abstractmethod
     def set_served_session_id(self, k: str, v: str):
-        """sets the session id for state of a key 'k'."""
+        """Sets the session id for state of a key 'k'."""
         pass
 
 
@@ -155,6 +153,7 @@ class _LightningAppRef:
     def get_current(cls) -> Optional["LightningApp"]:
         if cls._app_instance:
             return cls._app_instance
+        return None
 
 
 def affiliation(component: "Component") -> Tuple[str, ...]:
@@ -318,12 +317,11 @@ def _set_child_name(component: "Component", child: "Component", new_name: str) -
 def _delta_to_app_state_delta(root: "LightningFlow", component: "Component", delta: Delta) -> Delta:
     delta_dict = delta.to_dict()
     for changed in delta_dict.values():
-        for delta_key in changed.copy().keys():
+        for delta_key in changed.copy():
             val = changed[delta_key]
 
             new_prefix = "root"
             for p, c in _walk_to_component(root, component):
-
                 if isinstance(c, lightning_app.core.LightningWork):
                     new_prefix += "['works']"
 
@@ -352,6 +350,7 @@ def _walk_to_component(
     """Returns a generator that runs through the tree starting from the root down to the given component.
 
     At each node, yields parent and child as a tuple.
+
     """
     from lightning_app.structures import Dict, List
 
@@ -469,6 +468,7 @@ def _load_state_dict(root_flow: "LightningFlow", state: Dict[str, Any], strict:
         root_flow: The flow at the top of the component tree.
         state: The collected state dict.
         strict: Whether to validate all components have been re-created.
+
     """
     # 1: Reload the state of the existing works
     for w in root_flow.works():
@@ -580,42 +580,3 @@ def _is_headless(app: "LightningApp") -> bool:
             if "target" in entry:
                 return False
     return True
-
-
-def _handle_is_headless(app: "LightningApp"):
-    """Utility for runtime-specific handling of changes to the ``is_headless`` property."""
-    app_id = os.getenv("LIGHTNING_CLOUD_APP_ID", None)
-    project_id = os.getenv("LIGHTNING_CLOUD_PROJECT_ID", None)
-
-    if app_id is None or project_id is None:
-        return
-
-    from lightning_app.utilities.network import LightningClient
-
-    client = LightningClient()
-    list_apps_response = client.lightningapp_instance_service_list_lightningapp_instances(project_id=project_id)
-
-    current_lightningapp_instance: Optional[Externalv1LightningappInstance] = None
-    for lightningapp_instance in list_apps_response.lightningapps:
-        if lightningapp_instance.id == app_id:
-            current_lightningapp_instance = lightningapp_instance
-            break
-
-    if not current_lightningapp_instance:
-        return
-
-    if any(
-        [
-            current_lightningapp_instance.spec.is_headless == app.is_headless,
-            current_lightningapp_instance.status.phase != V1LightningappInstanceState.RUNNING,
-        ]
-    ):
-        return
-
-    current_lightningapp_instance.spec.is_headless = app.is_headless
-
-    client.lightningapp_instance_service_update_lightningapp_instance(
-        project_id=project_id,
-        id=current_lightningapp_instance.id,
-        body=AppinstancesIdBody(name=current_lightningapp_instance.name, spec=current_lightningapp_instance.spec),
-    )
