@@ -17,27 +17,23 @@ import os
 import re
 from dataclasses import asdict, dataclass, field
 from pathlib import Path
-from typing import Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Dict, List, Optional, Union
 
 from typing_extensions import Self
 
-import lightning_app as L
 from lightning_app.utilities.app_helpers import Logger
 from lightning_app.utilities.packaging.cloud_compute import CloudCompute
 
+if TYPE_CHECKING:
+    from lightning_app.core.work import LightningWork
+
 logger = Logger(__name__)
 
 
 def load_requirements(
     path_dir: str, file_name: str = "base.txt", comment_char: str = "#", unfreeze: bool = True
 ) -> List[str]:
-    """Load requirements from a file.
-
-    >>> from lightning_app import _PROJECT_ROOT
-    >>> path_req = os.path.join(_PROJECT_ROOT, "requirements")
-    >>> load_requirements(path_req, "docs.txt")  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE +SKIP
-    ['sphinx>=4.0', ...]
-    """
+    """Load requirements from a file."""
     path = os.path.join(path_dir, file_name)
     if not os.path.isfile(path):
         return []
@@ -87,6 +83,7 @@ class BuildConfig:
         image: The base image that the work runs on. This should be a publicly accessible image from a registry that
             doesn't enforce rate limits (such as DockerHub) to pull this image, otherwise your application will not
             start.
+
     """
 
     requirements: List[str] = field(default_factory=list)
@@ -117,10 +114,11 @@ class BuildConfig:
                     return ["apt-get install libsparsehash-dev"]
 
             BuildConfig(requirements=["git+https://github.com/mit-han-lab/torchsparse.git@v1.4.0"])
+
         """
         return []
 
-    def on_work_init(self, work: "L.LightningWork", cloud_compute: Optional["CloudCompute"] = None) -> None:
+    def on_work_init(self, work: "LightningWork", cloud_compute: Optional["CloudCompute"] = None) -> None:
         """Override with your own logic to load the requirements or dockerfile."""
         found_requirements = self._find_requirements(work)
         if self.requirements:
@@ -146,7 +144,7 @@ class BuildConfig:
             self.dockerfile = found_dockerfile
         self._prepare_dockerfile()
 
-    def _find_requirements(self, work: "L.LightningWork", filename: str = "requirements.txt") -> List[str]:
+    def _find_requirements(self, work: "LightningWork", filename: str = "requirements.txt") -> List[str]:
         # 1. Get work file
         file = _get_work_file(work)
         if file is None:
@@ -159,7 +157,7 @@ class BuildConfig:
             return []
         return [r for r in requirements if r != "lightning"]
 
-    def _find_dockerfile(self, work: "L.LightningWork", filename: str = "Dockerfile") -> Optional[str]:
+    def _find_dockerfile(self, work: "LightningWork", filename: str = "Dockerfile") -> Optional[str]:
         # 1. Get work file
         file = _get_work_file(work)
         if file is None:
@@ -169,6 +167,7 @@ class BuildConfig:
         dockerfile = os.path.join(dirname, filename)
         if os.path.isfile(dockerfile):
             return dockerfile
+        return None
 
     def _prepare_requirements(self) -> None:
         requirements = []
@@ -200,7 +199,7 @@ class BuildConfig:
         return cls(**d["__build_config__"])
 
 
-def _get_work_file(work: "L.LightningWork") -> Optional[str]:
+def _get_work_file(work: "LightningWork") -> Optional[str]:
     cls = work.__class__
     try:
         return inspect.getfile(cls)
