@@ -26,31 +26,30 @@ from copy import deepcopy
 from dataclasses import dataclass, field
 from functools import partial
 from threading import Event, Thread
-from typing import Any, Callable, Dict, Generator, Optional, Set, Tuple, Type, TYPE_CHECKING, Union
+from typing import TYPE_CHECKING, Any, Callable, Dict, Generator, Optional, Set, Tuple, Type, Union
 
 from deepdiff import DeepDiff, Delta
 from lightning_utilities.core.apply_func import apply_to_collection
 
 from lightning_app.core import constants
 from lightning_app.core.queues import MultiProcessQueue
-from lightning_app.storage import Path
 from lightning_app.storage.copier import _Copier, _copy_files
-from lightning_app.storage.drive import _maybe_create_drive, Drive
-from lightning_app.storage.path import _path_to_work_artifact
+from lightning_app.storage.drive import Drive, _maybe_create_drive
+from lightning_app.storage.path import Path, _path_to_work_artifact
 from lightning_app.storage.payload import Payload
 from lightning_app.utilities.app_helpers import affiliation
 from lightning_app.utilities.component import _set_work_context
 from lightning_app.utilities.enum import (
     CacheCallsKeys,
-    make_status,
     WorkFailureReasons,
     WorkStageStatus,
     WorkStopReasons,
+    make_status,
 )
 from lightning_app.utilities.exceptions import CacheMissException, LightningSigtermStateException
 
 if TYPE_CHECKING:
-    from lightning_app import LightningWork
+    from lightning_app.core import LightningWork
     from lightning_app.core.queues import BaseQueue
 
 from lightning_app.utilities.app_helpers import Logger
@@ -79,7 +78,6 @@ def unwrap(fn):
 def _send_data_to_caller_queue(
     proxy, work: "LightningWork", caller_queue: "BaseQueue", data: Dict, call_hash: str
 ) -> Dict:
-
     proxy.has_sent = True
 
     if work._calls[CacheCallsKeys.LATEST_CALL_HASH] is None:
@@ -135,22 +133,16 @@ class ProxyWorkRun:
 
         data = {"args": args, "kwargs": kwargs, "call_hash": call_hash}
 
-        # The if/else conditions are left un-compressed to simplify readability
-        # for the readers.
-        if self.work.cache_calls:
-            if not entered or stopped_on_sigterm:
-                _send_data_to_caller_queue(self, self.work, self.caller_queue, data, call_hash)
-            else:
-                if returned:
-                    return
+        # The if/else conditions are left un-compressed to simplify readability for the readers.
+        if not entered or stopped_on_sigterm:
+            _send_data_to_caller_queue(self, self.work, self.caller_queue, data, call_hash)
         else:
-            if not entered or stopped_on_sigterm:
+            if self.work.cache_calls and returned:
+                return
+            if returned or stopped_on_sigterm:
+                # the previous task has completed and we can re-queue the next one.
+                # overriding the return value for next loop iteration.
                 _send_data_to_caller_queue(self, self.work, self.caller_queue, data, call_hash)
-            else:
-                if returned or stopped_on_sigterm:
-                    # the previous task has completed and we can re-queue the next one.
-                    # overriding the return value for next loop iteration.
-                    _send_data_to_caller_queue(self, self.work, self.caller_queue, data, call_hash)
         if not self.work.parallel:
             raise CacheMissException("Task never called before. Triggered now")
 
@@ -159,6 +151,7 @@ class ProxyWorkRun:
 
         Currently, this performs a check against strings that look like filesystem paths and may need to be wrapped with
         a Lightning Path by the user.
+
         """
 
         def warn_if_pathlike(obj: Union[os.PathLike, str]):
@@ -179,8 +172,8 @@ class ProxyWorkRun:
 
     @staticmethod
     def _process_call_args(args: Tuple[Any, ...], kwargs: Dict[str, Any]) -> Tuple[Tuple[Any, ...], Dict[str, Any]]:
-        """Processes all positional and keyword arguments before they get passed to the caller queue and sent to
-        the LightningWork.
+        """Processes all positional and keyword arguments before they get passed to the caller queue and sent to the
+        LightningWork.
 
         Currently, this method only applies sanitization to Lightning Path objects.
 
@@ -190,6 +183,7 @@ class ProxyWorkRun:
 
         Returns:
             The positional and keyword arguments in the same order they were passed in.
+
         """
 
         def sanitize(obj: Union[Path, Drive]) -> Union[Path, Dict]:
@@ -207,8 +201,8 @@ class ProxyWorkRun:
 
     @staticmethod
     def _convert_hashable(args: Tuple[Any, ...], kwargs: Dict[str, Any]) -> Tuple[Tuple[Any, ...], Dict[str, Any]]:
-        """Processes all positional and keyword arguments before they get passed to the caller queue and sent to
-        the LightningWork.
+        """Processes all positional and keyword arguments before they get passed to the caller queue and sent to the
+        LightningWork.
 
         Currently, this method only applies sanitization to Hashable Objects.
 
@@ -218,6 +212,7 @@ class ProxyWorkRun:
 
         Returns:
             The positional and keyword arguments in the same order they were passed in.
+
         """
         from lightning_app.utilities.types import Hashable
 
@@ -228,9 +223,9 @@ class ProxyWorkRun:
 
 
 class WorkStateObserver(Thread):
-    """This thread runs alongside LightningWork and periodically checks for state changes. If the state changed
-    from one interval to the next, it will compute the delta and add it to the queue which is connected to the
-    Flow. This enables state changes to be captured that are not triggered through a setattr call.
+    """This thread runs alongside LightningWork and periodically checks for state changes. If the state changed from
+    one interval to the next, it will compute the delta and add it to the queue which is connected to the Flow. This
+    enables state changes to be captured that are not triggered through a setattr call.
 
     Args:
         work: The LightningWork for which the state should be monitored
@@ -245,6 +240,7 @@ class WorkStateObserver(Thread):
             def run(self):
                 # This update gets sent to the Flow once the thread compares the new state with the previous one
                 self.list.append(1)
+
     """
 
     def __init__(
@@ -304,10 +300,10 @@ class WorkStateObserver(Thread):
                 try:
                     with _state_observer_lock:
                         self._work.apply_flow_delta(Delta(deep_diff, raise_errors=True))
-                except Exception as e:
+                except Exception as ex:
                     print(traceback.print_exc())
-                    self._error_queue.put(e)
-                    raise e
+                    self._error_queue.put(ex)
+                    raise ex
 
     def join(self, timeout: Optional[float] = None) -> None:
         self._exit_event.set()
@@ -316,8 +312,8 @@ class WorkStateObserver(Thread):
 
 @dataclass
 class LightningWorkSetAttrProxy:
-    """This wrapper around the ``LightningWork.__setattr__`` ensures that state changes get sent to the delta queue
-    to be reflected in the Flow.
+    """This wrapper around the ``LightningWork.__setattr__`` ensures that state changes get sent to the delta queue to
+    be reflected in the Flow.
 
     Example:
 
@@ -326,6 +322,7 @@ class LightningWorkSetAttrProxy:
 
             def run(self):
                 self.var += 1  # This update gets sent to the Flow immediately
+
     """
 
     work_name: str
@@ -386,8 +383,7 @@ class WorkRunExecutor:
             queue_type = queue.pop("type")
             if queue_type == "redis":
                 return RedisQueue.from_dict(queue)
-            else:
-                return HTTPQueue.from_dict(queue)
+            return HTTPQueue.from_dict(queue)
         return queue
 
 
@@ -422,19 +418,19 @@ class WorkRunner:
                         self.state_observer.join(0)
                     self.state_observer = None
                 self.copier.join(0)
-            except LightningSigtermStateException as e:
+            except LightningSigtermStateException as ex:
                 logger.debug("Exiting")
-                os._exit(e.exit_code)
-            except Exception as e:
+                os._exit(ex.exit_code)
+            except Exception as ex:
                 # Inform the flow the work failed. This would fail the entire application.
-                self.error_queue.put(e)
+                self.error_queue.put(ex)
                 # Terminate the threads
                 if self.state_observer:
                     if self.state_observer.started:
                         self.state_observer.join(0)
                     self.state_observer = None
                 self.copier.join(0)
-                raise e
+                raise ex
 
     def setup(self):
         from lightning_app.utilities.state import AppState
@@ -501,8 +497,9 @@ class WorkRunner:
         # Set the internal IP address.
         # Set this here after the state observer is initialized, since it needs to record it as a change and send
         # it back to the flow
-        default_internal_ip = "127.0.0.1" if constants.LIGHTNING_CLOUDSPACE_HOST is None else "0.0.0.0"
-        self.work._internal_ip = os.environ.get("LIGHTNING_NODE_IP", default_internal_ip)
+        default_internal_ip = "127.0.0.1" if constants.LIGHTNING_CLOUDSPACE_HOST is None else "0.0.0.0"  # noqa: S104
+        self.work._internal_ip = os.environ.get("LIGHTNING_NODE_PRIVATE_IP", default_internal_ip)
+        self.work._public_ip = os.environ.get("LIGHTNING_NODE_IP", "")
 
         # 8. Patch the setattr method of the work. This needs to be done after step 4, so we don't
         # send delta while calling `set_state`.
@@ -532,9 +529,9 @@ class WorkRunner:
         # If an exception is raised, send a `FAILED` status delta to the flow and call the `on_exception` hook.
         try:
             ret = self.run_executor_cls(self.work, work_run, self.delta_queue)(*args, **kwargs)
-        except LightningSigtermStateException as e:
-            raise e
-        except BaseException as e:
+        except LightningSigtermStateException as ex:
+            raise ex
+        except BaseException as ex:
             # 10.2 Send failed delta to the flow.
             reference_state = deepcopy(self.work.state)
             exp, val, tb = sys.exc_info()
@@ -566,16 +563,15 @@ class WorkRunner:
                     id=self.work_name, delta=Delta(DeepDiff(reference_state, self.work.state, verbose_level=2))
                 )
             )
-            self.work.on_exception(e)
+            self.work.on_exception(ex)
             print("########## CAPTURED EXCEPTION ###########")
             print(traceback.print_exc())
             print("########## CAPTURED EXCEPTION ###########")
             return
 
         # 13. Destroy the state observer.
-        if self.run_executor_cls.enable_start_observer:
-            if self.state_observer.started:
-                self.state_observer.join(0)
+        if self.run_executor_cls.enable_start_observer and self.state_observer.started:
+            self.state_observer.join(0)
         self.state_observer = None
 
         # 14. Copy all artifacts to the shared storage so other Works can access them while this Work gets scaled down
@@ -645,6 +641,7 @@ class WorkRunner:
 
         Returns:
             The positional and keyword arguments in the same order they were passed in.
+
         """
 
         def _attach_work_and_get(transporter: Union[Path, Payload, dict]) -> Union[Path, Drive, dict, Any]:
@@ -689,8 +686,7 @@ class WorkRunner:
                 self.delta_queue.put(ComponentDelta(id=self.work_name, delta=delta))
                 self._proxy_setattr(cleanup=True)
                 return True
-            else:
-                raise Exception("Only the `start` action is supported right now !")
+            raise Exception("Only the `start` action is supported right now !")
         return False
 
 
@@ -699,6 +695,7 @@ def persist_artifacts(work: "LightningWork") -> None:
     storage.
 
     Files that don't exist or do not originate from the given Work will be skipped.
+
     """
     artifact_paths = [getattr(work, name) for name in work._paths]
     # only copy files that belong to this Work, i.e., when the path's origin refers to the current Work
