@@ -26,7 +26,7 @@ from requests.exceptions import ConnectionError
 from lightning_app.core.constants import APP_SERVER_HOST, APP_SERVER_PORT
 from lightning_app.storage.drive import _maybe_create_drive
 from lightning_app.utilities.app_helpers import AppStatePlugin, BaseStatePlugin, Logger
-from lightning_app.utilities.network import _configure_session
+from lightning_app.utilities.network import LightningClient, _configure_session
 
 logger = Logger(__name__)
 
@@ -50,6 +50,7 @@ def headers_for(context: Dict[str, str]) -> Dict[str, str]:
 
 class AppState:
     _APP_PRIVATE_KEYS: Tuple[str, ...] = (
+        "_use_localhost",
         "_host",
         "_session_id",
         "_state",
@@ -92,11 +93,11 @@ class AppState:
             my_affiliation: A tuple describing the affiliation this app state represents. When storing a state dict
                 on this AppState, this affiliation will be used to reduce the scope of the given state.
             plugin: A plugin to handle authorization.
+
         """
-        use_localhost = "LIGHTNING_APP_STATE_URL" not in os.environ
-        self._host = host or APP_SERVER_HOST
-        self._port = port or (APP_SERVER_PORT if use_localhost else None)
-        self._url = f"{self._host}:{self._port}" if use_localhost else self._host
+        self._use_localhost = "LIGHTNING_APP_STATE_URL" not in os.environ
+        self._host = host or ("http://127.0.0.1" if self._use_localhost else None)
+        self._port = port or (APP_SERVER_PORT if self._use_localhost else None)
         self._last_state = last_state
         self._state = state
         self._session_id = "1234"
@@ -105,11 +106,25 @@ class AppState:
         self._attach_plugin(plugin)
         self._session = self._configure_session()
 
+    @property
+    def _url(self) -> str:
+        if self._host is None:
+            app_ip = ""
+
+            if "LIGHTNING_CLOUD_PROJECT_ID" in os.environ and "LIGHTNING_CLOUD_APP_ID" in os.environ:
+                client = LightningClient()
+                app_instance = client.lightningapp_instance_service_get_lightningapp_instance(
+                    os.environ.get("LIGHTNING_CLOUD_PROJECT_ID"),
+                    os.environ.get("LIGHTNING_CLOUD_APP_ID"),
+                )
+                app_ip = app_instance.status.ip_address
+
+            # TODO: Don't hard code port 8080 here
+            self._host = f"http://{app_ip}:8080" if app_ip else APP_SERVER_HOST
+        return f"{self._host}:{self._port}" if self._use_localhost else self._host
+
     def _attach_plugin(self, plugin: Optional[BaseStatePlugin]) -> None:
-        if plugin is not None:
-            plugin = plugin
-        else:
-            plugin = AppStatePlugin()
+        plugin = plugin if plugin is not None else AppStatePlugin()
         self._plugin = plugin
 
     @staticmethod
@@ -118,6 +133,7 @@ class AppState:
 
         For example, if the affiliation is ``("root", "subflow")``, then the returned state will be
         ``state["flows"]["subflow"]``.
+
         """
         children_state = state
         for name in my_affiliation:
@@ -152,8 +168,8 @@ class AppState:
             try:
                 # TODO: Send the delta directly to the REST API.
                 response = self._session.post(app_url, json=data, headers=headers)
-            except ConnectionError as e:
-                raise AttributeError("Failed to connect and send the app state. Is the app running?") from e
+            except ConnectionError as ex:
+                raise AttributeError("Failed to connect and send the app state. Is the app running?") from ex
 
             if response and response.status_code != 200:
                 raise Exception(f"The response from the server was {response.status_code}. Your inputs were rejected.")
@@ -172,8 +188,8 @@ class AppState:
             sleep(0.5)
             try:
                 response = self._session.get(app_url, headers=headers, timeout=1)
-            except ConnectionError as e:
-                raise AttributeError("Failed to connect and fetch the app state. Is the app running?") from e
+            except ConnectionError as ex:
+                raise AttributeError("Failed to connect and fetch the app state. Is the app running?") from ex
 
             self._authorized = response.status_code
             if self._authorized != 200:
@@ -197,12 +213,12 @@ class AppState:
                 return _maybe_create_drive("root." + ".".join(self._my_affiliation), value)
             return value
 
-        elif name in self._state.get("works", {}):
+        if name in self._state.get("works", {}):
             return AppState(
                 self._host, self._port, last_state=self._last_state["works"][name], state=self._state["works"][name]
             )
 
-        elif name in self._state.get("flows", {}):
+        if name in self._state.get("flows", {}):
             return AppState(
                 self._host,
                 self._port,
@@ -210,7 +226,7 @@ class AppState:
                 state=self._state["flows"][name],
             )
 
-        elif name in self._state.get("structures", {}):
+        if name in self._state.get("structures", {}):
             return AppState(
                 self._host,
                 self._port,
