@@ -15,7 +15,7 @@
 import typing as t
 from typing import Protocol, runtime_checkable
 
-from lightning_app import LightningFlow, LightningWork
+from lightning_app.core import LightningFlow, LightningWork
 from lightning_app.structures import Dict, List
 
 Component = t.Union[LightningFlow, LightningWork, Dict, List]
@@ -24,5 +24,4 @@ ComponentTuple = (LightningFlow, LightningWork, Dict, List)
 
 @runtime_checkable
 class Hashable(Protocol):
-    def to_dict(self) -> t.Dict[str, t.Any]:
-        ...
+    def to_dict(self) -> t.Dict[str, t.Any]: ...
